package rabbit.client.sample;

import java.io.IOException;
import rabbit.client.ClientBase;
import rabbit.client.ClientListenerAdapter;
import rabbit.client.CountingClientBaseStopper;
import rabbit.http.HttpHeader;
import rabbit.httpio.WebConnectionResourceSource;
import rabbit.util.Logger;

/** A class that performs a set HEAD request to the given urls.
 *  This is mostly an example of how to use the rabbit client classes.
 *
 * @author <a href="mailto:robo@khelekore.org">Robert Olofsson</a>
 */
public class Head {
    private final ClientBase clientBase;
    private final CountingClientBaseStopper ccbs;
    
    public static void main (String[] args) {
	try {
	    Head h = new Head ();
	    h.head (args);
	} catch (IOException e) {
	    e.printStackTrace ();
	}
    }

    public Head () throws IOException {
	clientBase = new ClientBase ();
	ccbs = new CountingClientBaseStopper (clientBase);
    }

    public void head (String[] urls) throws IOException {
	for (String url : urls) 
	    head (url);
    }

    public void head (String url) throws IOException {
	ccbs.sendRequest (clientBase.getRequest ("HEAD", url),
			  new HeadListener (clientBase.getLogger ()));
    }

    private class HeadListener extends ClientListenerAdapter {   
	public HeadListener (Logger logger) {
	    super (logger);
	}

	@Override public void redirectedTo (String url) throws IOException {
	    head (url);
	}

	@Override 
	public void handleResponse (HttpHeader request, HttpHeader response, 
				    WebConnectionResourceSource wc) {
	    System.out.print (request.getRequestURI () + "\n" + response);
	    wc.release ();
	    requestDone (request);
	}

	@Override public void requestDone (HttpHeader request) {
	    ccbs.requestDone ();
	}
    }
}
