package rabbit.httpio;

import java.net.InetAddress;
import java.net.URL;
import java.net.UnknownHostException;
import rabbit.dns.DNSHandler;
import rabbit.io.InetAddressListener;

/** A dns lookup class that runs in the background.
 *
 * @author <a href="mailto:robo@khelekore.org">Robert Olofsson</a>
 */
public class ResolvRunner implements Runnable {
    private final TaskRunner tr;
    private final DNSHandler dnsHandler;
    private final URL url;
    private final InetAddressListener ial;

    public ResolvRunner (TaskRunner tr, DNSHandler dnsHandler, 
			 URL url, InetAddressListener ial) {
	this.tr = tr;
	this.dnsHandler = dnsHandler;
	this.url = url;
	this.ial = ial;
    }

    public void run () {
	try {
	    final InetAddress ia = dnsHandler.getInetAddress (url);
	    tr.runMainTask (new Runnable () {
		    public void run () {
			ial.lookupDone (ia);
		    }
		});
	} catch (final UnknownHostException e) {
	    tr.runMainTask (new Runnable () {
		    public void run () {
			ial.unknownHost (e);
		    }
		});
	}
    }
}
